#
# spec file for package toxic
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           toxic
Version:        0.11.3
Release:        lp155.1.3
Summary:        Console Tox-based instant messenging client
License:        GPL-3.0-only
Group:          Productivity/Networking/Instant Messenger
URL:            https://github.com/Tox/toxic
Source0:        https://github.com/JFreegman/toxic/archive/v%{version}.tar.gz#./%{name}-%{version}.tar.gz
Source1:        https://github.com/JFreegman/toxic/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(freealut)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libsodium)
BuildRequires:  pkgconfig(ncursesw) >= 6.0
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(toxcore)
BuildRequires:  pkgconfig(vpx)
BuildRequires:  pkgconfig(x11)

%description
Toxic is a Tox-based instant messenging client which formerly resided in the
Tox core repository, and is now available as a standalone application.

%prep
%setup -q

%build
%make_build \
    USER_CFLAGS="%{optflags}" \
    PREFIX="%{_prefix}"

%install
%make_install PREFIX="%{_prefix}"
%suse_update_desktop_file -G Toxic toxic
%suse_update_desktop_file -r toxic Network InstantMessaging

%files
%doc README.md
%license LICENSE
%{_bindir}/toxic
%{_datadir}/applications/toxic.desktop
%{_mandir}/man1/toxic.1%{?ext_man}
%{_mandir}/man5/toxic.conf.5%{?ext_man}
%dir %{_datadir}/toxic
%{_datadir}/toxic/nameservers
%{_datadir}/toxic/toxic.conf.example
%dir %{_datadir}/toxic/sounds
%{_datadir}/toxic/sounds/*.wav

%changelog
* Mon Feb 14 2022 ecsos <ecsos@opensuse.org>
- Update to 0.11.3
  * New Features
  - File transfers can now be queued for offline friends
  * Bug Fixes
  - Typing notifications work properly again
  - File transfers are properly canceled when a friend is deleted
    or blocked
  - Fix compile errors when building without audio support
* Fri Dec 10 2021 ecsos <ecsos@opensuse.org>
- Update to 0.11.2
  * New Features and Enhancements
  - The type of connection you have with a friend (UDP or TCP) is
    now shown in their respective window's top status bar
  - The type of connection you have to the Tox network is now
    shown in the home screen's top status bar
  - User statuses (away, busy) are now separated from connection
    status
  - Greatly reduce the amount of unnecessary window redrawing
    (fixes high CPU usage when idling and screen flickering on
    some machines)
  - The window refresh rate is now set dynamically for games
  - Reduce sound notification polling by a factor of 10
    (addresses high CPU usage when idling)
  - Tab-completion is now case-sensitive
  - Notes can now be empty (use the /note command with no argument)
  - The /add command no longer requires quotes around the request
    message
  * Bug Fixes
  - Fix a graphical bug on some terminal emulators related to the
    game border
  - Fix an outdated help menu entry
  - Fix possible buffer overrun in python API module
    (only affected user input)
  - Fix some multi-threading data races
  - VAD threshold (noise cancellation sensitivity) now properly
    defaults to the value set in the toxic config file for 1-on-1
    calls
- Changes from 0.11.1
  * New Features
  - Implemented a 2-D game engine and accompanying API with basic
    network support. Four games are included: Centipede, Snake,
    Conway's Game of Life, and Chess (online support only).
    The game module does not require additional libraries and is
    enabled by default build options. It can be disabled with the
    DISABLE_GAMES=1 build flag.
  * Bug Fixes
  - Fixed a rare race condition related to sound notifications
  - When a window is closed, the previous window is selected
    instead of the Home window
  - The /clear command now works in the Home window
- Changes from 0.11.0
  No changelog from upstream.
* Wed Apr 14 2021 ecsos <ecsos@opensuse.org>
- Update to 0.10.1
  * New Features
  - Add ability to customize Toxic's colour scheme via config file
  * Bug fixes
  - No longer announce when "ghost peers" exit a conference
    (this is caused by connection issues)
  - Fix off-by-one error related to text scrolling
  - Fix minor display bug with the A/V call info box
  - Fix bug sometimes causing join announcement spam on conference join
  * Other changes
  - Renamed some Makefile variables for consistency
  - Added a build script for creating minimal static binaries
- Changes from 0.10.0
  * New Features
  - A complete UI overhaul (Before, After)
  - Window no longer scrolls on output if the output is not
    already at the bottom of the window
  - Show a small indicator in the bottom left of the window tab
    when output scrolling is paused
  - Show join/part messages in conferences (this was removed in
    recent years but has now been re-implemented)
  * Bug fixes
  - Fix bug causing notification counter in window tab to increment
    by 2 on certain events
  * Other changes
  - Removed some unnecessary compile flags for ASAN builds
    (These flags are currently only necessary when compiling with
  - O3; the release build compiles with -O2)
  - Updated some default settings and config example entries to
    reflect recent changes
  - Attempt to handle nanosleep() errors
- Changes from 0.9.1
  * New features
  - Added a push-to-talk option for audio conferences
    (audio config setting: push_to_talk)
  - Added config setting allowing audio input to be set to mono or stereo
    (audio config settings: chat_audio_channels and conference_audio_channels respectively)
  * Improvements
  - Conferences now have persistent logs which behave identically
    to normal chat logs
  - Implemented word wrapping
  - The info bar showing active chats now minimizes the window
    tab name unless highlighted,
    allowing for many more windows to be open simultaneously without
    having them run off the screen
  - Chat tabs in the bottom bar now show the number of unread messages
  * Bug fixes
  - Fix bug that caused the window to occasionally not scroll down
    the correct number of lines on output
  - Fix bug sometimes preventing typing status from being updated
  - Fix bug causing glitchy sound notifications introduced in v0.9.0
  - Fix bug causing an empty message to be sent when a message fails
    internally to convert from widechar to multibyte
  - Fix bug causing tab complete to fail to complete a file/directory's line
    if there was only one item in the directory
  - Fix bug causing empty chat log files to be created when logging is disabled
  * Other changes
  - Added Makefile options for building with a release build
    (optimizations enabled and debug symbols disabled) and - for
    building with LLVM Address Sanitizer
    (ENABLE_RELEASE=1 and ENABLE_ASAN=1 respectively)
  - Removed seconds from the default timestamp format
  - Removed code for an unfinished/stale X11 feature (Drag 'n drop)
    and refactored remaining X11 screen focus code
- Changes from 0.9.0
  * New features
  - Conference audio chats
  * Bug fixes
  - Fix use after free bug on audio calls
  - Fix bug causing file names for incoming file transfers to be
    truncated if they were too long
  - Fix bug preventing failed inbound file transfers from being
    properly cleaned up in some instances
  - No longer allow invalid Posix file names for inbound file
    transfers
  - Fix race condition causing a null dereference in some
    instances related to desktop notifications
  - Fix rare bug where toxic would send its avatar as a regular
    file transfer after a peer has a network hickup during the
    initial avatar file transfer
  * Other changes
  - Audio implementation re-write
  - Refactor and greatly speed up outbound message queue
  - Greatly reduce stack memory allocations to ensure compatibility
    with musl's smaller default stack limit
  - Switch to using c99 standard from gnu99
  - Convert all variable length arrays to dynamic allocations
    (Toxic no longer uses VLA's for memory safety reasons)
  - Remove legacy code for backwards compatible tox save files
    created >5 years ago
  - Replaced deprecated usleep function with nanosleep
  - Rename groupchats -> conferences
  - Lots of misc. code cleanup and refactoring
- Changes from 0.8.4
  * New features
  - Add config option to set data file auto-save frequency
  - Add option for toxcore logging
  - Add ability to log to file
  - Add option to disable LAN
  - Add ability to skip words in input field via ctrl+left/right
    arrows
  * Bug fixes
  - Fix bug preventing bell notifications from working when
    compiled without X11
  - Fix auto-complete bugs
  - Fix A/V bug sometimes preventing caller from being informed
    of call termination
  - Fix A/V related build issues
  - Fix segfault on starting video
  - Fix groupchat peer scrolling bug
  - Fix bug preventing saved conference titles from loading on
    startup
  * Other changes
  - Change group peerlist scrolling key binding to ctrl+up/down
    arrows
  - No longer allow using the /add command for friends in the
    block list
  - Many misc. build fixes/improvements
* Sat Dec 22 2018 ecsos@opensuse.org
- update to 0.8.3
  - Enclosing quotes are no longer required for multi-word command
    arguments or file paths
  - Improved issues related to long message send delays in poor
    network conditions
  - Allow for empty status messages
  - Fixed tab-complete bug that added a forward slash to files with
    no file extension
  - Fixed OSX build issues
  - Various build/portability improvements
  - Update/improve install instructions
  - Numerous minor bug fixes and optimization improvements
* Wed May 16 2018 ecsos@opensuse.org
- fix build with new toxcore wich now build with cmake
* Thu Mar 22 2018 sleep_walker@opensuse.org
- update to 0.8.2
  - Repair operating system checks (#474)
  - Dynamically allocate audio calls structure
  - Fix comment
  - Fix typedef enums and potential uninitialised value.
  - Treat Tox_Options as opaque struct: no deref, no alloc.
  - Fix autocomplete bug
  - Update toxav API calls
  - Update API
  - re-add group peer list sorting
  - Re-implement group nick change notifications
  - add a .travis file and some build fixes
  - Update readme
  - Fix persistent groupchat loading
- add tarball signature
- improve checks makefile changes
- drop post and postun as they expanded to empty lines
* Sat Dec 30 2017 sleep_walker@opensuse.org
- adopt package from by ecsos
- use c-toxcore-devel instead of toxcore devel
- clean with spec-cleaner
- transform to pkgconfig dependencies
* Thu Dec  7 2017 ecsos@opensuse.org
- update to 0.8.1
  - Added a new command /bitrate that allows one to change the
    audio bitrate
  - Fixed compiling issues for *BSD systems
  - The /status command now prints a message indicating the status
    has been changed
  - Fix issue with redundant UI redrawing that would cause
    flickering on some systems
  - The /lsdev command refreshes the device list in the event that
    the available devices have changed
  - UI, formatting, and general bug fixes
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 0.8.0
  - Added python scripting interface (see documentation in apidoc
    directory)
  - Added run option to show toxic/toxcore version and removed them
    from the interface
  - Minor misc. fixes
* Thu Jan 12 2017 ecsos@opensuse.org
- update to 0.7.2
  - Ported toxcore implementation to tokok/c-toxcore
  - Allow saving QR code to png image
* Mon Sep 26 2016 ecsos@opensuse.org
- update to 0.7.1
  * Features and functionality:
  - Rewrite DHT bootstrapping to automatically fetch and update
    nodes list (also added config option to disable or change
    update frequency)
  - UI improvements for file transfers
  - Add support for password managers
  - Add option to toggle showing friend connection notifications
  - Add toggle-able input mode that allows multi-line text
    pasting
  - Add support for custom nospam values
  - Add support for terminal bell on certain events (see config)
  * Notable bug fixes:
  - Fix UI flicker on some terminals/systems
  - Fix tab complete bug that would sometimes clear the input box
  - Fix cross-client audio issues
  - Fix numerous A/V race conditions
* Sat Jan  2 2016 ecsos@opensuse.org
- switch from git version to stable version 0.7.0
* Tue Aug  5 2014 zawertun@gmail.com
- Initial package version
